@@ -1,6 +1,7 @@
 #!/bin/sh
 # shellcheck shell=sh
 # shellcheck source=/dev/null
+# shellcheck disable=SC2312
 
 # Copyright 2019 Intel Corporation
 # SPDX-License-Identifier: MIT
@@ -29,7 +30,7 @@
 # Overview
 
 # This is the top-level environment variable setup script for use with Intel
-# OneAPI toolkits. Most "tools" or "components" that are part of an Intel
+# oneAPI toolkits. Most "tools" or "components" that are part of an Intel
 # oneAPI installation include an `env/vars.sh` script that configures the
 # environment variables needed for that specific tool to work. More details
 # are available via this script's "--help" argument.
@@ -190,8 +191,8 @@ save_args() {
   echo " "
 }
 
-# Save a master copy of the arguments array ($@) passed to this script so we
-# can restore it, if needed later.
+# Save a copy of the arguments array ($@) passed to this script so we can
+# restore it, if needed later.
 script_args=$(save_args "$@")
 
 
@@ -234,21 +235,41 @@ prep_for_eval() {
 #   /script/absolute/pathname
 
 # executing function in a *subshell* to localize vars and effects on `cd`
+
+# The sequence `builtin cd` needs to be used with zsh instead of `command cd`
+# to remove alias/function redefinitions of the `cd` command. This is because
+# `command` only works with external commands in the zsh shell. Unfortunately,
+# `builtin` is not recognized by `dash` and fails. Thus it is necessary to
+# create two branches in the function to insure that an existing redefinition
+# of `cd` (alias or function) does not interfere.
+
 get_script_path() (
   script="$1"
   while [ -L "$script" ] ; do
-    # combining next two lines fails in zsh shell
     script_dir=$(command dirname -- "$script")
+    # TODO: coordinate with component env/vars.sh scripts to fix throughout
+    # see also: https://superuser.com/a/1574553/229501
     script_dir=$(cd "$script_dir" && command pwd -P)
+    # if [ -n "${ZSH_VERSION:-}" ] ; then
+    #   script_dir=$(builtin cd "$script_dir" && command pwd -P)
+    # else
+    #   script_dir=$(command cd "$script_dir" && command pwd -P)
+    # fi
     script="$(readlink "$script")"
     case $script in
       (/*) ;;
        (*) script="$script_dir/$script" ;;
     esac
   done
-  # combining next two lines fails in zsh shell
   script_dir=$(command dirname -- "$script")
+  # TODO: coordinate with component env/vars.sh scripts to fix throughout
+  # see also: https://superuser.com/a/1574553/229501
   script_dir=$(cd "$script_dir" && command pwd -P)
+  # if [ -n "${ZSH_VERSION:-}" ] ; then
+  #   script_dir=$(builtin cd "$script_dir" && command pwd -P)
+  # else
+  #   script_dir=$(command cd "$script_dir" && command pwd -P)
+  # fi
   printf "%s" "$script_dir"
 )
 
@@ -676,6 +697,7 @@ if [ "$temp_var" -eq 0 ] ; then
   echo ":: ERROR: No env scripts found: No \"env/vars.sh\" scripts to process."
   echo "   This can be caused by a bad or incomplete \"--config\" file."
   echo "   Can also be caused by an incomplete or missing oneAPI installation."
+  echo "   Can also be caused by redefining 'cd' via an alias or function."
   # Restore original $@ array before return.
   usage
   eval set -- "$script_args" || true
